@@ -1,6 +1,8 @@
 from dataclasses import dataclass
 from enum import Enum
 
+import jwt
+
 
 class Action(str, Enum):
     AUTH = 'auth'
@@ -14,6 +16,12 @@ class PastaportoAction:
     action: Action
     payload: dict[str, str]
 
+    def sign(self, secret: str) -> str:
+        return jwt.encode({
+            'action': self.action,
+            'payload': self.payload
+        }, str(secret), algorithm="HS256")
+
 
 def create_pastaporto_action(action: Action, payload: dict[str, str]) -> PastaportoAction:
     return PastaportoAction(action=action, payload=payload)
