@@ -1,4 +1,4 @@
-import datetime
+from datetime import datetime, timedelta
 
 import jwt
 from pythonit_toolkit.pastaporto.entities import Credential
@@ -15,18 +15,19 @@ def fake_pastaporto_token_for_user(
         {
             "userInfo": {"id": user["id"], "email": user["email"]},
             "credentials": credentials,
-            "exp": datetime.now() + datetime.timedelta(minutes=1),
+            "exp": datetime.now() + timedelta(minutes=1),
         },
         secret,
         algorithm="HS256",
     )
 
+
 def fake_service_to_service_token(secret: str, *, issuer: str, audience: str):
     return jwt.encode(
         {
-            'iss': issuer,
-            'aud': audience,
-            "exp": datetime.now() + datetime.timedelta(minutes=1),
+            "iss": issuer,
+            "aud": audience,
+            "exp": datetime.now() + timedelta(minutes=1),
         },
         secret,
         algorithm="HS256",
